summaryrefslogtreecommitdiff
path: root/sites
diff options
context:
space:
mode:
authorDries Buytaert <dries@buytaert.net>2005-04-14 18:34:31 +0000
committerDries Buytaert <dries@buytaert.net>2005-04-14 18:34:31 +0000
commit0f24a52770718be5340b26a5fded3e75da6dd82a (patch)
tree84a1eca27d17d26e19eb2ac34a9554b3cb13798c /sites
parentdb8dfcae39d50edf3f482617b90d78145728a2de (diff)
downloadbrdo-0f24a52770718be5340b26a5fded3e75da6dd82a.tar.gz
brdo-0f24a52770718be5340b26a5fded3e75da6dd82a.tar.bz2
- Patch #19800 by Daniel: make default $db_url informative and unique.
Diffstat (limited to 'sites')
-rw-r--r--sites/default/settings.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/sites/default/settings.php b/sites/default/settings.php
index 50499134e..92b1f2042 100644
--- a/sites/default/settings.php
+++ b/sites/default/settings.php
@@ -37,8 +37,8 @@
*
* Note that the $db_url variable gets parsed using PHP's built-in
* URL parser (i.e. using the "parse_url()" function) so make sure
* not to confuse the parser. If your db_user, db_password,
* db_hostname, or db_name contain characters used to delineate
* $db_url parts, you can escape them via URI hex encodings:
*
* : = %3a / = %2f @ = %40
@@ -75,10 +75,10 @@
* );
*
* Database URL format:
- * $db_url = 'mysql://db_user:db_password@db_hostname/db_name';
- * $db_url = 'pgsql://db_user:db_password@db_hostname/db_name';
+ * $db_url = 'mysql://username:password@localhost/database';
+ * $db_url = 'pgsql://username:password@localhost/database';
*/
-$db_url = 'mysql://drupal:drupal@localhost/drupal';
+$db_url = 'mysql://username:password@localhost/database';
$db_prefix = '';
/**
@@ -37,8 +37,8 @@
* Note that the $db_url variable gets parsed using PHP's built-in
* URL parser (i.e. using the "parse_url()" function) so make sure
- * not to confuse the parser. If your db_user, db_password,
- * db_hostname, or db_name contain characters used to delineate
+ * not to confuse the parser. If your username, password
+ * or database name contain characters used to delineate
* $db_url parts, you can escape them via URI hex encodings:
*